ConstraintError

Enum ConstraintError 

#[repr(i32)]
pub enum ConstraintError { Check = 275, CommitHook = 531, DataType = 3_091, ForeignKey = 787, Function = 1_043, NotNull = 1_299, Pinned = 2_835, PrimaryKey = 1_555, RowId = 2_579, Trigger = 1_811, Unique = 2_067, VTab = 2_323, }

Variants



Check = 275

A CHECK constraint failed.



CommitHook = 531

A commit hook callback returned non-zero that thus caused the SQL statement to be rolled back.



DataType = 3_091

An insert or update attempted to store a value inconsistent with the column’s declared type in a table defined as STRICT.



ForeignKey = 787

A foreign key constraint failed.



Function = 1_043

Available for use by extension functions.



NotNull = 1_299

A NOT NULL constraint failed.



Pinned = 2_835

An UPDATE trigger attempted to delete the row that was being updated in the middle of the update.



PrimaryKey = 1_555

A PRIMARY KEY constraint failed.



RowId = 2_579

A rowid is not unique.



Trigger = 1_811

A RAISE function within a trigger fired, causing the SQL statement to abort.



Unique = 2_067

A UNIQUE constraint failed.



VTab = 2_323

Available for use by application-defined virtual tables.