ErrorReason

Enum ErrorReason 

#[non_exhaustive]
pub enum ErrorReason {
Show 14 variants Aborted(AbortError), Authorization(AuthorizationError), Busy(BusyError), CantOpen(CantOpenError), Constraint(ConstraintError), Corrupt(CorruptError), Error(GeneralError), Io(IoError), Locked(LockedError), ReadOnly(ReadOnlyError), Row(RowError), Fetch(FetchError), Parameter(ParameterError), TextEncoding(TextEncodingError),
}
Extended SQLite result codes that provide more specific information about errors.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Aborted(AbortError)

Specific reasons for an ErrorCategory::Aborted.



Authorization(AuthorizationError)

Specific reason for an ErrorCategory::Authorization.



Busy(BusyError)

Specific reason for an ErrorCategory::Busy.



CantOpen(CantOpenError)

Specific reason for an ErrorCategory::CantOpen.



Constraint(ConstraintError)

Specific reason for an ErrorCategory::Constraint.



Corrupt(CorruptError)

Specific reason for an ErrorCategory::Corrupt.



Error(GeneralError)

Specific reason for an ErrorCategory::Unknown.



Io(IoError)

Specific reason for an ErrorCategory::Io.



Locked(LockedError)

Specific reason for an ErrorCategory::Locked.



ReadOnly(ReadOnlyError)

Specific reason for an ErrorCategory::ReadOnly.



Row(RowError)

Specific reason for an ErrorCategory::Row.

(This error code is defined by Squire; not SQLite. No SQLite result codes correspond to ErrorReason::Row.)



Fetch(FetchError)

Specific reason for an ErrorCategory::Fetch.

(This error code is defined by Squire; not SQLite. No SQLite result codes correspond to ErrorReason::Fetch.)



Parameter(ParameterError)

Specific reason for an ErrorCategory::Parameter.

(This error code is defined by Squire; not SQLite. No SQLite result codes correspond to ErrorReason::Parameter.)



TextEncoding(TextEncodingError)

Specific reason for an ErrorCategory::TextEncoding.

(This error code is defined by Squire; not SQLite. No SQLite result codes correspond to ErrorReason::Parameter.)

Implementations

Source

impl ErrorReason

pub const fn is_aborted(&self) -> bool

Returns true if this value is of type Aborted. Returns false otherwise

pub const fn is_authorization(&self) -> bool

Returns true if this value is of type Authorization. Returns false otherwise

pub const fn is_busy(&self) -> bool

Returns true if this value is of type Busy. Returns false otherwise

pub const fn is_cant_open(&self) -> bool

Returns true if this value is of type CantOpen. Returns false otherwise

pub const fn is_constraint(&self) -> bool

Returns true if this value is of type Constraint. Returns false otherwise

pub const fn is_corrupt(&self) -> bool

Returns true if this value is of type Corrupt. Returns false otherwise

pub const fn is_error(&self) -> bool

Returns true if this value is of type Error. Returns false otherwise

pub const fn is_io(&self) -> bool

Returns true if this value is of type Io. Returns false otherwise

pub const fn is_locked(&self) -> bool

Returns true if this value is of type Locked. Returns false otherwise

pub const fn is_read_only(&self) -> bool

Returns true if this value is of type ReadOnly. Returns false otherwise

pub const fn is_row(&self) -> bool

Returns true if this value is of type Row. Returns false otherwise

pub const fn is_fetch(&self) -> bool

Returns true if this value is of type Fetch. Returns false otherwise

pub const fn is_parameter(&self) -> bool

Returns true if this value is of type Parameter. Returns false otherwise

pub const fn is_text_encoding(&self) -> bool

Returns true if this value is of type TextEncoding. Returns false otherwise

Source

impl ErrorReason

pub const fn category(self) -> ErrorCategory

Returns the primary error category for this extended error code.

pub const fn code(self) -> ErrorCode

Returns the underlying ErrorCode.

pub const fn from_code(code: ErrorCode) -> Option<Self>

Find the ErrorReason for an ErrorCode.

pub const fn from_raw_code(code: i32) -> Option<Self>

Find the ErrorReason for a SQLite result code.