IoError

Enum IoError 

#[repr(i32)]
pub enum IoError {
Show 33 variants Read = 266, Write = 778, FSync = 1_034, FStat = 1_802, Truncate = 1_546, Unlock = 2_058, ReadLock = 2_314, Delete = 2_570, Blocked = 2_826, NoMem = 3_082, Access = 3_338, CheckReservedLock = 3_594, Lock = 3_850, Close = 4_106, DirClose = 4_362, ShmOpen = 4_618, ShmSize = 4_874, ShmLock = 5_130, ShmMap = 5_386, Seek = 5_642, DeleteNoEnt = 5_898, MMap = 6_154, GetTempPath = 6_410, ConvPath = 6_666, VNode = 6_922, Auth = 7_178, BeginAtomic = 7_434, CommitAtomic = 7_690, RollbackAtomic = 7_946, Data = 8_202, CorruptFS = 8_458, ShortRead = 522, DirFSync = 1_290,
}
Specific reason for an ErrorCategory::Io.

Variants



Read = 266

I/O error while trying to read from a file on disk.



Write = 778

I/O error while trying to write into a file on disk.



FSync = 1_034

I/O error while trying to flush previously written content out of OS and/or disk-control buffers and into persistent storage.



FStat = 1_802

I/O error while trying to invoke fstat() on a file to determine information such as the file size or access permissions.



Truncate = 1_546

I/O error while trying to truncate a file to a smaller size.



Unlock = 2_058

I/O error within the xUnlock method on the sqlite3_io_methods object.



ReadLock = 2_314

I/O error within the xLock method while trying to obtain a read lock.



Delete = 2_570

I/O error within the xDelete method on the sqlite3_vfs object.



Blocked = 2_826

👎Deprecated

No longer used.



NoMem = 3_082

Sometimes returned by the VFS layer to indicate that an operation could not be completed due to the inability to allocate sufficient memory.



Access = 3_338

I/O error within the xAccess method on the sqlite3_vfs object.



CheckReservedLock = 3_594

I/O error within the xCheckReservedLock method on the sqlite3_io_methods object.



Lock = 3_850

I/O error in the advisory file locking logic.



Close = 4_106

I/O error within the xClose method on the sqlite3_io_methods object.



DirClose = 4_362

👎Deprecated

No longer used.



ShmOpen = 4_618

I/O error within the xShmMap method while trying to open a new shared memory segment.



ShmSize = 4_874

I/O error within the xShmMap method while trying to enlarge a “shm” file as part of WAL mode transaction processing.



ShmLock = 5_130

👎Deprecated

No longer used.



ShmMap = 5_386

I/O error within the xShmMap method while trying to map a shared memory segment into the process address space.



Seek = 5_642

I/O error within the xRead or xWrite methods while trying to seek a file descriptor to the beginning point of the file.



DeleteNoEnt = 5_898

I/O error indicating that the xDelete method failed because the file being deleted does not exist.



MMap = 6_154

I/O error within the xFetch or xUnfetch methods while trying to map or unmap part of the database file into the process address space.



GetTempPath = 6_410

The VFS is unable to determine a suitable directory in which to place temporary files.



ConvPath = 6_666

Used only by Cygwin VFS indicating that the cygwin_conv_path() system call failed.



VNode = 6_922

Code reserved for use by extensions.



Auth = 7_178

Code reserved for use by extensions.



BeginAtomic = 7_434

The underlying operating system reported an error on the SQLITE_FCNTL_BEGIN_ATOMIC_WRITE file-control.



CommitAtomic = 7_690

The underlying operating system reported an error on the SQLITE_FCNTL_COMMIT_ATOMIC_WRITE file-control.



RollbackAtomic = 7_946

The underlying operating system reported an error on the SQLITE_FCNTL_ROLLBACK_ATOMIC_WRITE file-control.



Data = 8_202

Used only by the checksum VFS shim to indicate that the checksum on a page of the database file is incorrect.



CorruptFS = 8_458

A seek or read failure was due to the request not falling within the file’s boundary rather than an ordinary device failure.



ShortRead = 522

A read attempt in the VFS layer was unable to obtain as many bytes as was requested.



DirFSync = 1_290

I/O error while trying to invoke fsync() on a directory.