ParameterError

Enum ParameterError 

#[repr(i32)]
pub enum ParameterError { Bind = 458, Range = 714, Resolve = 970, InvalidIndex = 1_226, }
An error passing prepared statement parameter(s) to SQLite.

(This error category is defined by Squire; not SQLite. No SQLite result codes correspond to ParameterError.)

Variants



Bind = 458

Binding a parameter failed; into_bind_value returned an error.



Range = 714

Binding a parameter failed; the value is out of range for the SQLite data type it would be bound as. (For example, trying to bind a u64 value that doesn’t fit in an i64.)



Resolve = 970

Resolving parameter index(es) failed; resolve returned an error.



InvalidIndex = 1_226

Creating a BindIndex failed because the input value was zero or negative.