ReadOnlyError

Enum ReadOnlyError 

#[repr(i32)]
pub enum ReadOnlyError { Recovery = 264, CantLock = 520, Rollback = 776, DbMoved = 1_032, CantInit = 1_288, Directory = 1_544, }
Specific reason for an ErrorCategory::ReadOnly.

Variants



Recovery = 264

A WAL mode database cannot be opened because the database file needs to be recovered and recovery requires write access but only read access is available.



CantLock = 520

SQLite is unable to obtain a read lock on a WAL mode database because the shared-memory file associated with that database is read-only.



Rollback = 776

A database cannot be opened because it has a hot journal that needs to be rolled back but cannot because the database is readonly.



DbMoved = 1_032

A database cannot be modified because the database file has been moved since it was opened.



CantInit = 1_288

The shared memory region used by WAL mode exists but its content is unreliable and unusable by the current process since the current process does not have write permission on the shared memory region.



Directory = 1_544

The database is read-only because process does not have permission to create a journal file in the same directory as the database.