ErrorCode

Struct ErrorCode 

pub struct ErrorCode(/* private fields */);
A SQLite error return code.

ErrorCode can also represent an error returned by Squire.

Implementations

Source

impl ErrorCode

pub const fn new(code: i32) -> Option<Self>

Wrap a return value from SQLite in an ErrorCode.

Returns None if code is 0.

pub const unsafe fn new_unchecked(code: i32) -> Self

Wrap a known-error return value from SQLite in an ErrorCode.

Safety

code must not be zero.

pub const fn raw(&self) -> i32

The error code itself as an i32.

pub const fn is_sqlite(&self) -> bool

true if this error code originated from within SQLite.

pub const fn is_squire(&self) -> bool

true if this error code originated from Squire, or a crate it integrates with.

pub const fn name(&self) -> Option<&'static str>

The name of the error code constant.

Errors from SQLite have a name starting with SQLITE_. Errors from Squire have a name starting with SQUIRE_ERROR.

pub fn description(&self) -> &'static str

A message describing this error.