Jsonb

Struct Jsonb 

pub struct Jsonb<T>(pub T);
Available on crate features jsonb and serde only.
A value which is stored in SQLite serialized as JSONB.

⚠️ Warning

Jsonb is implemented with serde_sqlite_jsonb, which provides its own implementation of the SQLite binary JSON format. This implementation may contain bugs not present in SQLite.

For a safer alternative, use Json instead, and convert to and from JSONB in your queries using the jsonb() and json() SQL functions.

Tuple Fields

0: T