Reservation

Struct Reservation 

pub struct Reservation(/* private fields */);
A request for SQLite to allocate a blob of a certain size.

When a Reservation is used as a prepared statement parameter, SQLite will create a BLOB of the requested length and set every byte in the blob to \0.

Implementations

Source

impl Reservation

pub const fn new(bytes: isize) -> Self

Create a Reservation.

pub const fn len(&self) -> usize

The number of bytes to reserve, as a usize.

pub const fn into_inner(self) -> isize

The number of bytes to reserve, as an isize.