pub struct Rows<'c, 's, C: ColumnIndexes, S = Binding<'c, 's>>where
S: Execute<'c, 's>,
'c: 's,{ /* private fields */ }Implementations
Sourceimpl<'c, 's, 'r, C, S> Rows<'c, 's, C, S>where
C: Columns<'r>,
S: Execute<'c, 's>,
'c: 's,
's: 'r,
impl<'c, 's, 'r, C, S> Rows<'c, 's, C, S>where
C: Columns<'r>,
S: Execute<'c, 's>,
'c: 's,
's: 'r,
Sourcepub fn next(&'r mut self) -> Result<Option<C>>
pub fn next(&'r mut self) -> Result<Option<C>>
Fetch the next row.
If fetching fails, returns an error. If no more rows are available,
returns Ok(None). Otherwise, returns Ok(Some(C)).
Sourcepub fn map<F, T: 's>(self, f: F) -> Map<'c, 's, C, F, S> ⓘwhere
F: FnMut(C) -> T,
pub fn map<F, T: 's>(self, f: F) -> Map<'c, 's, C, F, S> ⓘwhere
F: FnMut(C) -> T,
Call a closure to transform each row in the result set.
Like Iterator::map, but can map over Columns which borrow data
from the SQLite row. The returned T must not borrow from the row.
Sourcepub fn filter_map<F, T: 's>(self, f: F) -> FilterMap<'c, 's, C, F, S> ⓘ
pub fn filter_map<F, T: 's>(self, f: F) -> FilterMap<'c, 's, C, F, S> ⓘ
Call a closure to transform each row in the result set into an
Option, and filter out any rows where the closure returned None.
Like Iterator::filter_map, but can map over Columns which borrow
data from the SQLite row. The returned T must not borrow from the row.