#[repr(i32)]pub enum BusyError {
Recovery = 261,
Snapshot = 517,
Timeout = 773,
}Variants
Recovery = 261
An operation could not continue because another process is busy recovering a WAL mode database file following a crash.
Snapshot = 517
A database connection tries to promote a read transaction into a write transaction but finds that another database connection has already written to the database.
Timeout = 773
A blocking Posix advisory file lock request in the VFS layer failed due to a timeout.