#[repr(i32)]pub enum GeneralError {
MissingCollSeq = 257,
Retry = 513,
Snapshot = 769,
}Expand description
Specific reason for an ErrorCategory::Unknown.
Variants
MissingCollSeq = 257
A SQL statement could not be prepared because a collating sequence named in that SQL statement could not be located.
Retry = 513
Used internally to provoke sqlite3_prepare_v2() to try again to prepare a statement that failed with an error on the previous attempt.
Snapshot = 769
Returned when attempting to start a read transaction on an historical version of the database by using sqlite3_snapshot_open() interface.