#[repr(i32)]pub enum LockedError {
SharedCache = 262,
VTab = 518,
}Variants
Access to an SQLite data record is blocked by another database connection that is using the same record in shared cache mode.
VTab = 518
Not used by the SQLite core, but available for use by extensions.