pub struct Reservation(/* private fields */);Expand description
A request for SQLite to allocate a blob of a certain size.
When a Reservation is used as a prepared
statement parameter, SQLite will create a BLOB of the
requested length and set every byte in the blob to \0.
Implementations
Sourceimpl Reservation
impl Reservation